import moment from 'moment';
import { useEffect, useState, useMemo, useCallback  } from 'react';
import WeekCalendarBody from '../../components/WeekCalendar/WeekCalendarBody/WeekCalendarBody';
import WeekCalendarHeader from '../../components/WeekCalendar/WeekCalendarHeader/WeekCalendarHeader'
import { getWeekInfoString, getWeekFromCurrentDate } from '../../helpers/CalendarHelpers';


function WeekCalendar() {

  const [date, setDate] = useState({year: '', month: '', currentDay: ''})
  const [hourFormat, setHourFormat] = useState(false);

  useEffect(()=>{
    const year = new Date().getFullYear()
    const month = new Date().getMonth()
    const currentDay = moment().date()
    setDate({year: year, month: month, currentDay: currentDay})
  }, [])

  const week = useMemo(()=>{
    return getWeekFromCurrentDate(date.year, date.month, date.currentDay)
  }, [date])

  const incrementWeek = useCallback(() => {
    setDate((prevState)=>{
      const newDate = new Date(prevState.year, prevState.month, prevState.currentDay + 7)
      return {year: newDate.getFullYear(), month: newDate.getMonth(), currentDay: moment(newDate).date()}
    })
  }, [])

  const decrementWeek = useCallback(() => {
    setDate((prevState)=>{
      const newDate = new Date(prevState.year, prevState.month, prevState.currentDay - 7)
      return {year: newDate.getFullYear(), month: newDate.getMonth(), currentDay: moment(newDate).date()}
    })
  }, [])

  const weekInfo = useMemo(()=>{
    return getWeekInfoString(week, date)
  }, [date])
  
  return (
    <>
      <WeekCalendarHeader
        incrementWeek={incrementWeek}
        decrementWeek={decrementWeek}
        weekInfo={weekInfo}
      />
      <WeekCalendarBody
        week={week}
        date={date}
        hourFormat={hourFormat}
        setHourFormat={setHourFormat}
      />
      {week.join(' ')}
    </>
  );
}

export default WeekCalendar;